@@ -1,4 +1,4 @@
-use std::ops::{Deref, DerefMut};
+use std::ops::Deref;
 
 use crate::{error::GetDataError, FromRequest, Request, RequestBody, Result};
 
@@ -26,12 +26,6 @@ impl<T> Deref for Data<T> {
     }
 }
 
-impl<T> DerefMut for Data<T> {
-    fn deref_mut(&mut self) -> &mut Self::Target {
-        &mut self.0
-    }
-}
-
 #[async_trait::async_trait]
 impl<'a, T: Send + Sync + 'static> FromRequest<'a> for Data<&'a T> {
     type Error = GetDataError;
@@ -47,7 +41,7 @@ impl<'a, T: Send + Sync + 'static> FromRequest<'a> for Data<&'a T> {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::{handler, middleware::AddData, Endpoint, EndpointExt};
+    use crate::{handler, http::StatusCode, middleware::AddData, Endpoint, EndpointExt};
 
     #[tokio::test]
     async fn test_data_extractor() {
@@ -57,6 +51,32 @@ mod tests {
         }
 
         let app = index.with(AddData::new(100i32));
-        app.call(Request::builder().finish()).await;
+        app.call(Request::default()).await;
+    }
+
+    #[tokio::test]
+    async fn test_data_extractor_error() {
+        #[handler(internal)]
+        async fn index(_value: Data<&i32>) {
+            todo!()
+        }
+
+        let app = index;
+        let mut resp = app.call(Request::default()).await;
+        assert_eq!(resp.status(), StatusCode::INTERNAL_SERVER_ERROR);
+        assert_eq!(
+            resp.take_body().into_string().await.unwrap(),
+            "data of type `i32` was not found."
+        );
+    }
+
+    #[tokio::test]
+    async fn test_data_extractor_deref() {
+        #[handler(internal)]
+        async fn index(value: Data<&String>) {
+            assert_eq!(value.to_uppercase(), "ABC");
+        }
+        let app = index.with(AddData::new("abc".to_string()));
+        app.call(Request::default()).await;
     }
 }
